import { formatDate, getRandomFloat, getRandomInt, getRandomString, isNotBasicType } from './utils';
export var transType = function (oriData, type) {
    if (Array.isArray(oriData) && oriData.every(function (val) { return !isNotBasicType(val); })) {
        return transArrayType(oriData, type);
    }
    if (isNotBasicType(oriData)) {
        return oriData;
    }
    var value = null;
    try {
        switch (type) {
            case 'string':
                value = "" + oriData;
                break;
            case 'int':
                value = parseInt(oriData, 10);
                if (value !== value) {
                    throw new Error('int类型转换失败');
                }
                break;
            case 'float':
                value = parseFloat(oriData);
                if (value !== value) {
                    throw new Error('float类型转换失败');
                }
                break;
            case 'boolean':
                value = Boolean(oriData);
                break;
            case 'date':
                value = formatDate(oriData, 'Y-M-D');
                break;
            case 'time':
                value = formatDate(oriData, 'h:m:s');
                break;
            case 'datetime':
                value = formatDate(oriData);
                break;
            default:
                value = oriData;
                break;
        }
    }
    catch (error) {
        value = oriData;
    }
    return value;
};
export var transArrayType = function (oriData, type) { return oriData.map(function (val) { return transType(val, type); }); };
export var mockByType = function (type, length) {
    var value = '';
    switch (type) {
        case 'string':
            value = getRandomString(length);
            break;
        case 'int':
            value = getRandomInt(1, length);
            break;
        case 'float':
            value = getRandomFloat(length);
            break;
        case 'boolean':
            value = Math.random() <= 0.5;
            break;
        case 'date':
            value = formatDate(new Date(), 'Y-M-D');
            break;
        case 'time':
            value = formatDate(new Date(), 'h:m:s');
            break;
        case 'datetime':
            value = formatDate(new Date());
            break;
        default:
            value = '';
            break;
    }
    return value;
};
